pyxmpp2.sasl.core.Reply

Package pyxmpp2 :: Package sasl :: Module core :: Class Reply |
[hide private]

# Class Reply

Base class for SASL authentication reply objects.

Instance Methods | [hide private]
__init__(self, data=`'````'`, encode=True) Initialize the Reply object. |
`bytes` |
encode(self) Base64-encode the data contained in the reply when appropriate. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
`bool` | _encode whether to base64 encode the data or not
`bytes` | data optional reply data.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, data=`'````'`, encode=True) (Constructor) |
Initialize the Reply object. Parameters: `data` (`bytes`) - optional reply data. `encode` (`bool`) - whether to base64 encode the data or not Overrides: object.__init__

### encode(self) |
Base64-encode the data contained in the reply when appropriate. Returns: `bytes` encoded data.